@@ -18,14 +18,12 @@
 
 #include "stanzaextension.h"
 
-namespace jreen
+namespace Jreen
 {
 
-class Nickname : public StanzaExtension
+class Nickname : public Payload
 {
-	J_EXTENSION(jreen::Nickname,
-		   "/presence/nick[@xmlns='http://jabber.org/protocol/nick']"
-		   "|/message/nick[@xmlns='http://jabber.org/protocol/nick']")
+	J_PAYLOAD(Jreen::Nickname)
 public:
 	Nickname(const QString &nick);
 	const QString &nick() { return m_nick; }
